@@ -12,7 +12,7 @@
 html_dependency_spinkit <- function() {
   htmlDependency(
     name = "spinkit",
-    version = "0.1.0",
+    version = "0.1.1",
     src = list(href = "shinybusy", file = "assets"),
     package = "shinybusy",
     stylesheet = "spinkit/spin.min.css"
@@ -91,6 +91,8 @@ html_dependency_notiflix <- function() {
 
 #' @importFrom htmltools htmlDependency
 #' @importFrom utils packageVersion
+#' @export
+#' @rdname html-dependencies
 html_dependency_startup <- function() {
   htmlDependency(
     name = "shinybusy-startup",
@@ -100,6 +102,9 @@ html_dependency_startup <- function() {
     script = "startup.js"
   )
 }
+
+#' @export
+#' @rdname html-dependencies
 html_dependency_loading <- function() {
   htmlDependency(
     name = "shinybusy-loading",
@@ -109,6 +114,9 @@ html_dependency_loading <- function() {
     script = "loading.js"
   )
 }
+
+#' @export
+#' @rdname html-dependencies
 html_dependency_busy <- function() {
   htmlDependency(
     name = "shinybusy-busy",
@@ -118,6 +126,9 @@ html_dependency_busy <- function() {
     script = "busy.js"
   )
 }
+
+#' @export
+#' @rdname html-dependencies
 html_dependency_notify <- function() {
   htmlDependency(
     name = "shinybusy-notify",
@@ -127,6 +138,9 @@ html_dependency_notify <- function() {
     script = "notify.js"
   )
 }
+
+#' @export
+#' @rdname html-dependencies
 html_dependency_report <- function() {
   htmlDependency(
     name = "shinybusy-report",
@@ -136,3 +150,16 @@ html_dependency_report <- function() {
     script = "report.js"
   )
 }
+
+#' @export
+#' @rdname html-dependencies
+html_dependency_block <- function() {
+  htmlDependency(
+    name = "shinybusy-block",
+    version = packageVersion("shinybusy"),
+    src = list(file = "packer"),
+    package = "shinybusy",
+    script = "block.js",
+    head = "<style>.nx-block-temporary-position {opacity: 1!important;}</style>"
+  )
+}
